@@ -4,7 +4,7 @@ import os
 import threading
 import time
 # from ..Scheduler import IntervalTask
-from ..Scheduler import dbg, get_async_result
+from ..Scheduler import dbg
 from ..dbserver.base import Base, ENGINE_DICT, mysql, can_return_directly
 
 
